==> libxpertmass_1.3.0.orig.tar.gz: libxpertmass-1.3.0/source/XpertMassGui/src/DecimalPlacesOptionsDlg.cpp <==
/* BEGIN software license
 *
 * msXpertSuite - mass spectrometry software suite
 * -----------------------------------------------
 * Copyright(C) 2009,...,2018 Filippo Rusconi
 *
 * http://www.msxpertsuite.org
 *
 * This file is part of the msXpertSuite project.
 *
 * The msXpertSuite project is the successor of the massXpert project. This
 * project now includes various independent modules:
 *
 * - massXpert, model polymer chemistries and simulate mass spectrometric data;
 * - mineXpert, a powerful TIC chromatogram/mass spectrum viewer/miner;
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 *
 * END software license
 */


/////////////////////// Qt includes
#include <QMessageBox>
#include <QSettings>


/////////////////////// Local includes
#include "MsXpS/libXpertMassCore/globals.hpp"
#include "MsXpS/libXpertMassGui/DecimalPlacesOptionsDlg.hpp"

#include "ui_DecimalPlacesOptionsDlg.h"

namespace MsXpS
{
namespace libXpertMassGui
{

DecimalPlacesOptionsDlg::DecimalPlacesOptionsDlg(
  QWidget *parent, [[maybe_unused]] const QString &configSettingsFilePath)
  : QDialog(parent), mp_ui(new Ui::DecimalPlacesOptionsDlg)
{
  mp_ui->setupUi(this);

  QSettings settings(m_configSettingsFilePath, QSettings::IniFormat);

  settings.beginGroup("decimal_places_options_dlg");

  restoreGeometry(settings.value("geometry").toByteArray());

  settings.endGroup();

  // Make now the connections that we will rely upon when
  // reading places settings and set them to the widgets
  // which will be reported to the member data.
  connect(
    mp_ui->atomDecimalPlacesSpinBox, &QSpinBox::valueChanged, [&](int value) {
      m_atomDecPlaces = value;
    });

  connect(mp_ui->oligomerDecimalPlacesSpinBox,
          &QSpinBox::valueChanged,
          [&](int value) {
            m_oligomerDecPlaces = value;
          });

  connect(mp_ui->polymerDecimalPlacesSpinBox,
          &QSpinBox::valueChanged,
          [&](int value) {
            m_polymerDecPlaces = value;
          });

  connect(mp_ui->pKaPhPiDecimalPlacesSpinBox,
          &QSpinBox::valueChanged,
          [&](int value) {
            m_pkaPhPiDecPlaces = value;
          });

  connect(mp_ui->validatePushButton,
          &QPushButton::clicked,
          this,
          &DecimalPlacesOptionsDlg::validate);

  settings.beginGroup("decimal_places_options");

  updateDecimalPlaces(
    settings.value("ATOM_DEC_PLACES", libXpertMassCore::ATOM_DEC_PLACES).toInt(),
    settings.value("OLIGOMER_DEC_PLACES", libXpertMassCore::OLIGOMER_DEC_PLACES)
      .toInt(),
    settings.value("POLYMER_DEC_PLACES", libXpertMassCore::POLYMER_DEC_PLACES)
      .toInt(),
    settings.value("PKA_PH_PI_DEC_PLACES", libXpertMassCore::PKA_PH_PI_DEC_PLACES)
      .toInt());

  settings.endGroup();
}

DecimalPlacesOptionsDlg::~DecimalPlacesOptionsDlg()
{
}

void
DecimalPlacesOptionsDlg::updateDecimalPlaces(int atom,
                                             int oligo,
                                             int poly,
                                             int pka_ph)
{
  // Will automagically update the member data.
  mp_ui->atomDecimalPlacesSpinBox->setValue(atom);
  mp_ui->oligomerDecimalPlacesSpinBox->setValue(oligo);
  mp_ui->polymerDecimalPlacesSpinBox->setValue(poly);
  mp_ui->pKaPhPiDecimalPlacesSpinBox->setValue(pka_ph);
}

void
DecimalPlacesOptionsDlg::closeEvent(QCloseEvent *event)
{
  Q_UNUSED(event);

  QSettings settings(m_configSettingsFilePath, QSettings::IniFormat);

  settings.beginGroup("decimal_places_options_dlg");

  settings.setValue("geometry", saveGeometry());

  settings.setValue("ATOM_DEC_PLACES", m_atomDecPlaces);
  settings.setValue("OLIGOMER_DEC_PLACES", m_oligomerDecPlaces);
  settings.setValue("POLYMER_DEC_PLACES", m_polymerDecPlaces);
  settings.setValue("PKA_PH_PI_DEC_PLACES", m_pkaPhPiDecPlaces);

  settings.endGroup();
}

void
DecimalPlacesOptionsDlg::validate()
{

  libXpertMassCore::ATOM_DEC_PLACES = mp_ui->atomDecimalPlacesSpinBox->value();
  libXpertMassCore::OLIGOMER_DEC_PLACES =
    mp_ui->oligomerDecimalPlacesSpinBox->value();
  libXpertMassCore::POLYMER_DEC_PLACES =
    mp_ui->polymerDecimalPlacesSpinBox->value();
  libXpertMassCore::PKA_PH_PI_DEC_PLACES =
    mp_ui->pKaPhPiDecimalPlacesSpinBox->value();

  QSettings settings(m_configSettingsFilePath, QSettings::IniFormat);

  settings.beginGroup("decimal_places_options");

  settings.setValue("ATOM_DEC_PLACES", libXpertMassCore::ATOM_DEC_PLACES);
  settings.setValue("OLIGOMER_DEC_PLACES", libXpertMassCore::OLIGOMER_DEC_PLACES);
  settings.setValue("POLYMER_DEC_PLACES", libXpertMassCore::POLYMER_DEC_PLACES);
  settings.setValue("PKA_PH_PI_DEC_PLACES", libXpertMassCore::PKA_PH_PI_DEC_PLACES);

  settings.endGroup();

  // At this point ask that masses be redisplayed, for the sequence
  // editor window.

  emit decimalPlacesOptionsChangedSignal();
}

void
DecimalPlacesOptionsDlg::registerJsConstructor(QJSEngine *engine)
{
  if(!engine)
    {
      qWarning()
        << "Cannot register DecimalPlacesOptionsDlg class: engine is null";
      return;
    }

  // Register the meta object as a constructor

  QJSValue jsMetaObject =
    engine->newQMetaObject(&DecimalPlacesOptionsDlg::staticMetaObject);
  engine->globalObject().setProperty("DecimalPlacesOptionsDlg", jsMetaObject);
}


} // namespace libXpertMassGui

} // namespace MsXpS

==> libxpertmass_1.4.0.orig.tar.gz: libxpertmass-1.4.0/source/XpertMassGui/src/DecimalPlacesOptionsDlg.cpp <==
/* BEGIN software license
 *
 * msXpertSuite - mass spectrometry software suite
 * -----------------------------------------------
 * Copyright(C) 2009,...,2018 Filippo Rusconi
 *
 * http://www.msxpertsuite.org
 *
 * This file is part of the msXpertSuite project.
 *
 * The msXpertSuite project is the successor of the massXpert project. This
 * project now includes various independent modules:
 *
 * - massXpert, model polymer chemistries and simulate mass spectrometric data;
 * - mineXpert, a powerful TIC chromatogram/mass spectrum viewer/miner;
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 *
 * END software license
 */


/////////////////////// Qt includes
#include <QMessageBox>
#include <QSettings>


/////////////////////// Local includes
#include "MsXpS/libXpertMassCore/globals.hpp"
#include "MsXpS/libXpertMassGui/DecimalPlacesOptionsDlg.hpp"

#include "ui_DecimalPlacesOptionsDlg.h"

namespace MsXpS
{
namespace libXpertMassGui
{

/*!
\class MsXpS::libXpertMassGui::DecimalPlacesOptionsDlg
\inmodule libXpertMassGui
\ingroup XpertMassGuiUtilities
\inheaderfile DecimalPlacesOptionsDlg.hpp

\brief The DecimalPlacesOptionsDlg class provides a means to configure
the number of decimals that numbers should have when printed as text.
*/

/*!
\variable MsXpS::libXpertMassGui::DecimalPlacesOptionsDlg::m_atomDecPlaces

\brief The number of digits after the decimal separator symbol ('.') when
printing out the mass of atoms or isotopes (default = 10).
*/

/*!
\variable MsXpS::libXpertMassGui::DecimalPlacesOptionsDlg::m_oligomerDecPlaces

\brief The number of digits after the decimal separator symbol ('.') when
printing out the mass of oligomers (default = 6).
*/

/*!
\variable MsXpS::libXpertMassGui::DecimalPlacesOptionsDlg::m_polymerDecPlaces

\brief The number of digits after the decimal separator symbol ('.') when
printing out the mass of polymers (default = 3).
*/

/*!
\variable MsXpS::libXpertMassGui::DecimalPlacesOptionsDlg::m_pkaPhPiDecPlaces

\brief The number of digits after the decimal separator symbol ('.') when
printing out pH, pKa, pI values (default = 3).
*/


DecimalPlacesOptionsDlg::DecimalPlacesOptionsDlg(
  QWidget *parent, [[maybe_unused]] const QString &configSettingsFilePath)
  : QDialog(parent), mp_ui(new Ui::DecimalPlacesOptionsDlg)
{
  mp_ui->setupUi(this);

  QSettings settings(m_configSettingsFilePath, QSettings::IniFormat);

  settings.beginGroup("decimal_places_options_dlg");

  restoreGeometry(settings.value("geometry").toByteArray());

  settings.endGroup();

  // Make now the connections that we will rely upon when
  // reading places settings and set them to the widgets
  // which will be reported to the member data.
  connect(
    mp_ui->atomDecimalPlacesSpinBox, &QSpinBox::valueChanged, [&](int value) {
      m_atomDecPlaces = value;
    });

  connect(mp_ui->oligomerDecimalPlacesSpinBox,
          &QSpinBox::valueChanged,
          [&](int value) {
            m_oligomerDecPlaces = value;
          });

  connect(mp_ui->polymerDecimalPlacesSpinBox,
          &QSpinBox::valueChanged,
          [&](int value) {
            m_polymerDecPlaces = value;
          });

  connect(mp_ui->pKaPhPiDecimalPlacesSpinBox,
          &QSpinBox::valueChanged,
          [&](int value) {
            m_pkaPhPiDecPlaces = value;
          });

  connect(mp_ui->validatePushButton,
          &QPushButton::clicked,
          this,
          &DecimalPlacesOptionsDlg::validate);

  settings.beginGroup("decimal_places_options");

  updateDecimalPlaces(
    settings.value("ATOM_DEC_PLACES", libXpertMassCore::ATOM_DEC_PLACES)
      .toInt(),
    settings.value("OLIGOMER_DEC_PLACES", libXpertMassCore::OLIGOMER_DEC_PLACES)
      .toInt(),
    settings.value("POLYMER_DEC_PLACES", libXpertMassCore::POLYMER_DEC_PLACES)
      .toInt(),
    settings
      .value("PKA_PH_PI_DEC_PLACES", libXpertMassCore::PKA_PH_PI_DEC_PLACES)
      .toInt());

  settings.endGroup();
}

DecimalPlacesOptionsDlg::~DecimalPlacesOptionsDlg()
{
}

void
DecimalPlacesOptionsDlg::updateDecimalPlaces(int atom,
                                             int oligo,
                                             int poly,
                                             int pka_ph)
{
  // Will automagically update the member data.
  mp_ui->atomDecimalPlacesSpinBox->setValue(atom);
  mp_ui->oligomerDecimalPlacesSpinBox->setValue(oligo);
  mp_ui->polymerDecimalPlacesSpinBox->setValue(poly);
  mp_ui->pKaPhPiDecimalPlacesSpinBox->setValue(pka_ph);
}

void
DecimalPlacesOptionsDlg::closeEvent(QCloseEvent *event)
{
  Q_UNUSED(event);

  QSettings settings(m_configSettingsFilePath, QSettings::IniFormat);

  settings.beginGroup("decimal_places_options_dlg");

  settings.setValue("geometry", saveGeometry());

  settings.setValue("ATOM_DEC_PLACES", m_atomDecPlaces);
  settings.setValue("OLIGOMER_DEC_PLACES", m_oligomerDecPlaces);
  settings.setValue("POLYMER_DEC_PLACES", m_polymerDecPlaces);
  settings.setValue("PKA_PH_PI_DEC_PLACES", m_pkaPhPiDecPlaces);

  settings.endGroup();
}

void
DecimalPlacesOptionsDlg::validate()
{

  libXpertMassCore::ATOM_DEC_PLACES = mp_ui->atomDecimalPlacesSpinBox->value();
  libXpertMassCore::OLIGOMER_DEC_PLACES =
    mp_ui->oligomerDecimalPlacesSpinBox->value();
  libXpertMassCore::POLYMER_DEC_PLACES =
    mp_ui->polymerDecimalPlacesSpinBox->value();
  libXpertMassCore::PKA_PH_PI_DEC_PLACES =
    mp_ui->pKaPhPiDecimalPlacesSpinBox->value();

  QSettings settings(m_configSettingsFilePath, QSettings::IniFormat);

  settings.beginGroup("decimal_places_options");

  settings.setValue("ATOM_DEC_PLACES", libXpertMassCore::ATOM_DEC_PLACES);
  settings.setValue("OLIGOMER_DEC_PLACES",
                    libXpertMassCore::OLIGOMER_DEC_PLACES);
  settings.setValue("POLYMER_DEC_PLACES", libXpertMassCore::POLYMER_DEC_PLACES);
  settings.setValue("PKA_PH_PI_DEC_PLACES",
                    libXpertMassCore::PKA_PH_PI_DEC_PLACES);

  settings.endGroup();

  // At this point ask that masses be redisplayed, for the sequence
  // editor window.

  emit decimalPlacesOptionsChangedSignal();
}

void
DecimalPlacesOptionsDlg::registerJsConstructor(QJSEngine *engine)
{
  if(!engine)
    {
      qWarning()
        << "Cannot register DecimalPlacesOptionsDlg class: engine is null";
      return;
    }

  // Register the meta object as a constructor

  QJSValue jsMetaObject =
    engine->newQMetaObject(&DecimalPlacesOptionsDlg::staticMetaObject);
  engine->globalObject().setProperty("DecimalPlacesOptionsDlg", jsMetaObject);
}


} // namespace libXpertMassGui

} // namespace MsXpS
